Filesystem
===========

Filesystem represents abstract API definition. It is now implemented by :class:`conu.DockerContainerViaExportFS`

.. autoclass:: conu.apidefs.filesystem.Filesystem
   :members:

